document.addEventListener('DOMContentLoaded', function() {
  // Simulated ephemeris data (in real implementation, this would come from calculations)
  const planetaryData = {
    mercury: {
      ra: "12h 30m 15s",
      dec: "+15° 30' 25\"",
      dist: "0.387"
    },
    venus: {
      ra: "15h 45m 30s",
      dec: "-20° 15' 40\"",
      dist: "0.723"
    },
    mars: {
      ra: "18h 20m 45s",
      dec: "+25° 45' 10\"",
      dist: "1.524"
    },
    jupiter: {
      ra: "21h 15m 30s",
      dec: "-15° 20' 35\"",
      dist: "5.203"
    }
  };

  // Update planet data
  function updatePlanetData() {
    const planetCards = document.querySelectorAll('.planet-card');
    
    planetCards.forEach(card => {
      const planet = card.dataset.planet;
      const data = planetaryData[planet];
      
      card.querySelector('.ra').textContent = data.ra;
      card.querySelector('.dec').textContent = data.dec;
      card.querySelector('.dist').textContent = data.dist;
    });
  }

  // Add animation to planet cards
  const planetCards = document.querySelectorAll('.planet-card');
  planetCards.forEach(card => {
    card.addEventListener('click', function() {
      this.style.transform = 'scale(1.05)';
      setTimeout(() => {
        this.style.transform = 'translateY(-5px)';
      }, 200);
    });
  });

  // Initialize data
  updatePlanetData();

  // Update data every 60 seconds (in real implementation, this would be more sophisticated)
  setInterval(updatePlanetData, 60000);
});
